==> refcodes-graphical-1.2.7-sources.jar: org/refcodes/graphical/GridModeAccessor.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.graphical;

/**
 * Provides an accessor for a grid mode property.
 */
public interface GridModeAccessor {

	/**
	 * Retrieves the grid mode from the grid mode property.
	 * 
	 * @return The grid mode stored by the grid mode property.
	 */
	GridMode getGridMode();

	/**
	 * Provides a mutator for a grid mode property.
	 */
	public interface GridModeMutator {

		/**
		 * Sets the grid mode for the grid mode property.
		 * 
		 * @param aGridMode The grid mode to be stored by the grid mode
		 *        property.
		 */
		void setGridMode( GridMode aGridMode );
	}

	/**
	 * Provides a builder method for a grid mode property returning the builder
	 * for applying multiple build operations.
	 * 
	 * @param <B> The builder to return in order to be able to apply multiple
	 *        build operations.
	 */
	public interface GridModeBuilder<B extends GridModeBuilder<B>> {

		/**
		 * Sets the grid mode for the grid mode property.
		 * 
		 * @param aGridMode The grid mode to be stored by the grid mode
		 *        property.
		 * 
		 * @return The builder for applying multiple build operations.
		 */
		B withGridMode( GridMode aGridMode );
	}

	/**
	 * Provides a grid mode property.
	 */
	public interface GridModeProperty extends GridModeAccessor, GridModeMutator {}
}

==> refcodes-graphical-3.2.6-sources.jar: org/refcodes/graphical/GridModeAccessor.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.graphical;

/**
 * Provides an accessor for a grid mode property.
 */
public interface GridModeAccessor {

	/**
	 * Retrieves the grid mode from the grid mode property.
	 * 
	 * @return The grid mode stored by the grid mode property.
	 */
	GridMode getGridMode();

	/**
	 * Provides a mutator for a grid mode property.
	 */
	public interface GridModeMutator {

		/**
		 * Sets the grid mode for the grid mode property.
		 * 
		 * @param aGridMode The grid mode to be stored by the grid mode
		 *        property.
		 */
		void setGridMode( GridMode aGridMode );
	}

	/**
	 * Provides a builder method for a grid mode property returning the builder
	 * for applying multiple build operations.
	 * 
	 * @param <B> The builder to return in order to be able to apply multiple
	 *        build operations.
	 */
	public interface GridModeBuilder<B extends GridModeBuilder<B>> {

		/**
		 * Sets the grid mode for the grid mode property.
		 * 
		 * @param aGridMode The grid mode to be stored by the grid mode
		 *        property.
		 * 
		 * @return The builder for applying multiple build operations.
		 */
		B withGridMode( GridMode aGridMode );
	}

	/**
	 * Provides a grid mode property.
	 */
	public interface GridModeProperty extends GridModeAccessor, GridModeMutator {

		/**
		 * This method stores and passes through the given argument, which is
		 * very useful for builder APIs: Sets the given {@link GridMode}
		 * (setter) as of {@link #setGridMode(GridMode)} and returns the very
		 * same value (getter).
		 * 
		 * @param aGridMode The {@link GridMode} to set (via
		 *        {@link #setGridMode(GridMode)}).
		 * 
		 * @return Returns the value passed for it to be used in conclusive
		 *         processing steps.
		 */
		default GridMode letGridMode( GridMode aGridMode ) {
			setGridMode( aGridMode );
			return aGridMode;
		}
	}
}
